resources Changes
=================

* The ButlerURI code has been extracted from the ``daf_butler`` package and made into a standalone package. It is now known as `lsst.resources.ResourcePath` (DM-31723)
